==> jc-1.4.0.tar.gz: gnu/xml/transform/SystemPropertyFunction.h <==
// final class gnu.xml.transform.SystemPropertyFunction

// class file dependencies
// @dep_class 31a5fe383e259780 gnu_xml_transform_SystemPropertyFunction
// @dep_class d90c61647700b7f6 gnu_xml_xpath_Expr
// @dep_class 2a7152deee1944f1 java_lang_Object

// header file dependencies
// @dep_header gnu_xml_xpath_Expr

#include "gnu/xml/xpath/Expr.h"

#ifndef _JC_gnu_xml_transform_SystemPropertyFunction_H_
#define _JC_gnu_xml_transform_SystemPropertyFunction_H_

// Forward structure declarations
struct _jc_gnu_xml_xpath_Expr$object;
struct _jc_java_lang_Class$object;
struct _jc_java_lang_Object$object;
struct _jc_java_util_List$object;
struct _jc_javax_xml_namespace_QName$object;
struct _jc_org_w3c_dom_Node$object;

// Typedefs
typedef struct _jc_gnu_xml_transform_SystemPropertyFunction$sub_refs	_jc_gnu_xml_transform_SystemPropertyFunction$sub_refs;
typedef struct _jc_gnu_xml_transform_SystemPropertyFunction$sub_nonrefs	_jc_gnu_xml_transform_SystemPropertyFunction$sub_nonrefs;
typedef struct _jc_gnu_xml_transform_SystemPropertyFunction$refs	_jc_gnu_xml_transform_SystemPropertyFunction$refs;
typedef struct _jc_gnu_xml_transform_SystemPropertyFunction$nonrefs	_jc_gnu_xml_transform_SystemPropertyFunction$nonrefs;
typedef struct _jc_gnu_xml_transform_SystemPropertyFunction$object	_jc_gnu_xml_transform_SystemPropertyFunction$object;

typedef const struct _jc_gnu_xml_transform_SystemPropertyFunction$vmethods	_jc_gnu_xml_transform_SystemPropertyFunction$vmethods;
typedef const struct _jc_gnu_xml_transform_SystemPropertyFunction$vtable	_jc_gnu_xml_transform_SystemPropertyFunction$vtable;
typedef const struct _jc_gnu_xml_transform_SystemPropertyFunction$vtype	_jc_gnu_xml_transform_SystemPropertyFunction$vtype;

// Constructors
extern void _jc_gnu_xml_transform_SystemPropertyFunction$method$_init$52f4ad9f2989aeee(_jc_env *, struct _jc_gnu_xml_transform_SystemPropertyFunction$object *);

// Virtual methods
extern struct _jc_gnu_xml_xpath_Expr$object *_jc_gnu_xml_transform_SystemPropertyFunction$method$clone$8aac957948447f2f(_jc_env *, struct _jc_gnu_xml_transform_SystemPropertyFunction$object *, struct _jc_java_lang_Object$object *);
extern struct _jc_java_lang_Object$object *_jc_gnu_xml_transform_SystemPropertyFunction$method$evaluate$f399496e60bca5df(_jc_env *, struct _jc_gnu_xml_transform_SystemPropertyFunction$object *, struct _jc_object *);
extern struct _jc_java_lang_Object$object *_jc_gnu_xml_transform_SystemPropertyFunction$method$evaluate$8764614230b47559(_jc_env *, struct _jc_gnu_xml_transform_SystemPropertyFunction$object *, struct _jc_object *, jint, jint);
extern void _jc_gnu_xml_transform_SystemPropertyFunction$method$setArguments$09123773dfa6e512(_jc_env *, struct _jc_gnu_xml_transform_SystemPropertyFunction$object *, struct _jc_object *);
extern struct _jc_java_lang_Object$object *_jc_gnu_xml_transform_SystemPropertyFunction$method$systemProperty$f3aa26e81eb9f929(_jc_env *, struct _jc_gnu_xml_transform_SystemPropertyFunction$object *, struct _jc_javax_xml_namespace_QName$object *);

// Virtual method descriptors
extern _jc_method _jc_gnu_xml_transform_SystemPropertyFunction$method_info$clone$8aac957948447f2f;
extern _jc_method _jc_gnu_xml_transform_SystemPropertyFunction$method_info$evaluate$f399496e60bca5df;
extern _jc_method _jc_gnu_xml_transform_SystemPropertyFunction$method_info$evaluate$8764614230b47559;
extern _jc_method _jc_gnu_xml_transform_SystemPropertyFunction$method_info$setArguments$09123773dfa6e512;
extern _jc_method _jc_gnu_xml_transform_SystemPropertyFunction$method_info$systemProperty$f3aa26e81eb9f929;

// Virtual methods structure
struct _jc_gnu_xml_transform_SystemPropertyFunction$vmethods {
	struct _jc_gnu_xml_xpath_Expr$object	*(*clone$8aac957948447f2f)(_jc_env *, struct _jc_gnu_xml_transform_SystemPropertyFunction$object *, struct _jc_java_lang_Object$object *);
	struct _jc_java_lang_Object$object	*(*evaluate$f399496e60bca5df)(_jc_env *, struct _jc_gnu_xml_transform_SystemPropertyFunction$object *, struct _jc_object *);
	struct _jc_java_lang_Object$object	*(*evaluate$8764614230b47559)(_jc_env *, struct _jc_gnu_xml_transform_SystemPropertyFunction$object *, struct _jc_object *, jint, jint);
	void	(*setArguments$09123773dfa6e512)(_jc_env *, struct _jc_gnu_xml_transform_SystemPropertyFunction$object *, struct _jc_object *);
	struct _jc_java_lang_Object$object	*(*systemProperty$f3aa26e81eb9f929)(_jc_env *, struct _jc_gnu_xml_transform_SystemPropertyFunction$object *, struct _jc_javax_xml_namespace_QName$object *);
};

// Vtable
struct _jc_gnu_xml_transform_SystemPropertyFunction$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_gnu_xml_xpath_Expr$vmethods	gnu_xml_xpath_Expr;
	_jc_gnu_xml_transform_SystemPropertyFunction$vmethods	gnu_xml_transform_SystemPropertyFunction;
};

// Vtype
struct _jc_gnu_xml_transform_SystemPropertyFunction$vtype {
	_jc_type			type;
	_jc_gnu_xml_transform_SystemPropertyFunction$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_gnu_xml_transform_SystemPropertyFunction$sub_refs {
	struct _jc_object	*args;
};

// Reference instance fields (object)
struct _jc_gnu_xml_transform_SystemPropertyFunction$refs {
    _jc_gnu_xml_transform_SystemPropertyFunction$sub_refs	gnu_xml_transform_SystemPropertyFunction;
    _jc_gnu_xml_xpath_Expr$sub_refs	gnu_xml_xpath_Expr;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_gnu_xml_transform_SystemPropertyFunction$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_gnu_xml_transform_SystemPropertyFunction$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_gnu_xml_xpath_Expr$sub_nonrefs	gnu_xml_xpath_Expr;
    _jc_gnu_xml_transform_SystemPropertyFunction$sub_nonrefs	gnu_xml_transform_SystemPropertyFunction;
};

// Object instance structure
struct _jc_gnu_xml_transform_SystemPropertyFunction$object {
	_jc_gnu_xml_transform_SystemPropertyFunction$refs	refs[0];
	_jc_word		lockword;
	_jc_gnu_xml_transform_SystemPropertyFunction$vtype	*vtype;
	_jc_gnu_xml_transform_SystemPropertyFunction$nonrefs	nonrefs;
};

// Type structure
extern _jc_gnu_xml_transform_SystemPropertyFunction$vtype _jc_gnu_xml_transform_SystemPropertyFunction$type;

// Array types class info structures
_JC_DECL_ARRAYS(gnu_xml_transform_SystemPropertyFunction, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_gnu_xml_transform_SystemPropertyFunction$class_object;

#endif	/* _JC_gnu_xml_transform_SystemPropertyFunction_H_ */

==> jc-1.4.5.tar.gz: gnu/xml/transform/SystemPropertyFunction.h <==
// final class gnu.xml.transform.SystemPropertyFunction

// class file dependencies
// @dep_class 31a5fe383e259780 gnu_xml_transform_SystemPropertyFunction
// @dep_class d90c61647700b7f6 gnu_xml_xpath_Expr
// @dep_class 1c4f1fc002fc96e5 java_lang_Object

// header file dependencies
// @dep_header gnu_xml_xpath_Expr

#include "gnu/xml/xpath/Expr.h"

#ifndef _JC_gnu_xml_transform_SystemPropertyFunction_H_
#define _JC_gnu_xml_transform_SystemPropertyFunction_H_

// Forward structure declarations
struct _jc_gnu_xml_xpath_Expr$object;
struct _jc_java_lang_Class$object;
struct _jc_java_lang_Object$object;
struct _jc_java_util_List$object;
struct _jc_javax_xml_namespace_QName$object;
struct _jc_org_w3c_dom_Node$object;

// Typedefs
typedef struct _jc_gnu_xml_transform_SystemPropertyFunction$sub_refs	_jc_gnu_xml_transform_SystemPropertyFunction$sub_refs;
typedef struct _jc_gnu_xml_transform_SystemPropertyFunction$sub_nonrefs	_jc_gnu_xml_transform_SystemPropertyFunction$sub_nonrefs;
typedef struct _jc_gnu_xml_transform_SystemPropertyFunction$refs	_jc_gnu_xml_transform_SystemPropertyFunction$refs;
typedef struct _jc_gnu_xml_transform_SystemPropertyFunction$nonrefs	_jc_gnu_xml_transform_SystemPropertyFunction$nonrefs;
typedef struct _jc_gnu_xml_transform_SystemPropertyFunction$object	_jc_gnu_xml_transform_SystemPropertyFunction$object;

typedef const struct _jc_gnu_xml_transform_SystemPropertyFunction$vmethods	_jc_gnu_xml_transform_SystemPropertyFunction$vmethods;
typedef const struct _jc_gnu_xml_transform_SystemPropertyFunction$vtable	_jc_gnu_xml_transform_SystemPropertyFunction$vtable;
typedef const struct _jc_gnu_xml_transform_SystemPropertyFunction$vtype	_jc_gnu_xml_transform_SystemPropertyFunction$vtype;

// Constructors
extern void _jc_gnu_xml_transform_SystemPropertyFunction$method$_init$52f4ad9f2989aeee(_jc_env *, struct _jc_gnu_xml_transform_SystemPropertyFunction$object *) _JC_JCNI_ATTR;

// Virtual methods
extern struct _jc_gnu_xml_xpath_Expr$object *_jc_gnu_xml_transform_SystemPropertyFunction$method$clone$8aac957948447f2f(_jc_env *, struct _jc_gnu_xml_transform_SystemPropertyFunction$object *, struct _jc_java_lang_Object$object *) _JC_JCNI_ATTR;
extern struct _jc_java_lang_Object$object *_jc_gnu_xml_transform_SystemPropertyFunction$method$evaluate$f399496e60bca5df(_jc_env *, struct _jc_gnu_xml_transform_SystemPropertyFunction$object *, struct _jc_object *) _JC_JCNI_ATTR;
extern struct _jc_java_lang_Object$object *_jc_gnu_xml_transform_SystemPropertyFunction$method$evaluate$8764614230b47559(_jc_env *, struct _jc_gnu_xml_transform_SystemPropertyFunction$object *, struct _jc_object *, jint, jint) _JC_JCNI_ATTR;
extern void _jc_gnu_xml_transform_SystemPropertyFunction$method$setArguments$09123773dfa6e512(_jc_env *, struct _jc_gnu_xml_transform_SystemPropertyFunction$object *, struct _jc_object *) _JC_JCNI_ATTR;
extern struct _jc_java_lang_Object$object *_jc_gnu_xml_transform_SystemPropertyFunction$method$systemProperty$f3aa26e81eb9f929(_jc_env *, struct _jc_gnu_xml_transform_SystemPropertyFunction$object *, struct _jc_javax_xml_namespace_QName$object *) _JC_JCNI_ATTR;

// Virtual method descriptors
extern _jc_method _jc_gnu_xml_transform_SystemPropertyFunction$method_info$clone$8aac957948447f2f;
extern _jc_method _jc_gnu_xml_transform_SystemPropertyFunction$method_info$evaluate$f399496e60bca5df;
extern _jc_method _jc_gnu_xml_transform_SystemPropertyFunction$method_info$evaluate$8764614230b47559;
extern _jc_method _jc_gnu_xml_transform_SystemPropertyFunction$method_info$setArguments$09123773dfa6e512;
extern _jc_method _jc_gnu_xml_transform_SystemPropertyFunction$method_info$systemProperty$f3aa26e81eb9f929;

// Virtual methods structure
struct _jc_gnu_xml_transform_SystemPropertyFunction$vmethods {
	struct _jc_gnu_xml_xpath_Expr$object	*(*clone$8aac957948447f2f)(_jc_env *, struct _jc_gnu_xml_transform_SystemPropertyFunction$object *, struct _jc_java_lang_Object$object *) _JC_JCNI_ATTR;
	struct _jc_java_lang_Object$object	*(*evaluate$f399496e60bca5df)(_jc_env *, struct _jc_gnu_xml_transform_SystemPropertyFunction$object *, struct _jc_object *) _JC_JCNI_ATTR;
	struct _jc_java_lang_Object$object	*(*evaluate$8764614230b47559)(_jc_env *, struct _jc_gnu_xml_transform_SystemPropertyFunction$object *, struct _jc_object *, jint, jint) _JC_JCNI_ATTR;
	void	(*setArguments$09123773dfa6e512)(_jc_env *, struct _jc_gnu_xml_transform_SystemPropertyFunction$object *, struct _jc_object *) _JC_JCNI_ATTR;
	struct _jc_java_lang_Object$object	*(*systemProperty$f3aa26e81eb9f929)(_jc_env *, struct _jc_gnu_xml_transform_SystemPropertyFunction$object *, struct _jc_javax_xml_namespace_QName$object *) _JC_JCNI_ATTR;
};

// Vtable
struct _jc_gnu_xml_transform_SystemPropertyFunction$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_gnu_xml_xpath_Expr$vmethods	gnu_xml_xpath_Expr;
	_jc_gnu_xml_transform_SystemPropertyFunction$vmethods	gnu_xml_transform_SystemPropertyFunction;
};

// Vtype
struct _jc_gnu_xml_transform_SystemPropertyFunction$vtype {
	_jc_type			type;
	_jc_gnu_xml_transform_SystemPropertyFunction$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_gnu_xml_transform_SystemPropertyFunction$sub_refs {
	struct _jc_object	*args;
};

// Reference instance fields (object)
struct _jc_gnu_xml_transform_SystemPropertyFunction$refs {
    _jc_gnu_xml_transform_SystemPropertyFunction$sub_refs	gnu_xml_transform_SystemPropertyFunction;
    _jc_gnu_xml_xpath_Expr$sub_refs	gnu_xml_xpath_Expr;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_gnu_xml_transform_SystemPropertyFunction$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_gnu_xml_transform_SystemPropertyFunction$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_gnu_xml_xpath_Expr$sub_nonrefs	gnu_xml_xpath_Expr;
    _jc_gnu_xml_transform_SystemPropertyFunction$sub_nonrefs	gnu_xml_transform_SystemPropertyFunction;
};

// Object instance structure
struct _jc_gnu_xml_transform_SystemPropertyFunction$object {
	_jc_gnu_xml_transform_SystemPropertyFunction$refs	refs[0];
	_jc_word		lockword;
	_jc_gnu_xml_transform_SystemPropertyFunction$vtype	*vtype;
	_jc_gnu_xml_transform_SystemPropertyFunction$nonrefs	nonrefs;
};

// Type structure
extern _jc_gnu_xml_transform_SystemPropertyFunction$vtype _jc_gnu_xml_transform_SystemPropertyFunction$type;

// Array types class info structures
_JC_DECL_ARRAYS(gnu_xml_transform_SystemPropertyFunction, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_gnu_xml_transform_SystemPropertyFunction$class_object;

#endif	/* _JC_gnu_xml_transform_SystemPropertyFunction_H_ */
